@@ -71,13 +71,13 @@ def diff_lists(input: List, output: List, ptr: Pointer) -> Tuple[List, List]:
                 "path": ptr.append(idx_token),
                 "value": op["value"],
             }
-            return [ops + [full_op], padding + 1]
+            return [[*ops, full_op], padding + 1]
         elif op["op"] == "remove":
             full_op = {
                 "op": "remove",
                 "path": ptr.append(op["idx"] + padding),
             }
-            return [ops + [full_op], padding - 1]
+            return [[*ops, full_op], padding - 1]
         else:
             replace_ptr = ptr.append(op["idx"] + padding)
             replace_ops, _ = diff(op["original"], op["value"], replace_ptr)
