@@ -1,9 +1,10 @@
+from __future__ import annotations
+
 import re
 from typing import Any, Hashable, List, Tuple
 
 from .types import Diffable
 
-
 tilde0_re = re.compile("~0")
 tilde1_re = re.compile("~1")
 tilde_re = re.compile("~")
@@ -19,21 +20,21 @@ def escape(token: str) -> str:
 
 
 class Pointer:
-    def __init__(self, tokens: List[Hashable] = None) -> None:
+    def __init__(self, tokens: List[Hashable] | None = None) -> None:
         if tokens is None:
             tokens = []
-        self.tokens = tokens
+        self.tokens = tuple(tokens)
 
     @staticmethod
     def from_str(path: str) -> "Pointer":
-        tokens = [unescape(t) for t in path.split("/")]
+        tokens = [unescape(t) for t in path.split("/")[1:]]
         return Pointer(tokens)
 
     def __str__(self) -> str:
         return "/" + "/".join(escape(str(t)) for t in self.tokens)
 
     def __repr__(self) -> str:
-        return f"Pointer({repr(self.tokens)})"
+        return f"Pointer({list(self.tokens)!r})"
 
     def __hash__(self) -> int:
         return hash(self.tokens)
@@ -62,4 +63,4 @@ class Pointer:
 
     def append(self, token: Hashable) -> "Pointer":
         """append, creating new Pointer"""
-        return Pointer(self.tokens + [token])
+        return Pointer((*self.tokens, token))
